@@ -22,9 +22,11 @@
 #' example_dt %>%
 #'   dt_distinct(z)
 dt_distinct <- function(.data, ...) {
+  UseMethod("dt_distinct")
+}
 
-  if (!is.data.frame(.data)) stop(".data must be a data.frame or data.table")
-  if (!is.data.table(.data)) .data <- as.data.table(.data)
+#' @export
+dt_distinct.tidytable <- function(.data, ...) {
 
   dots <- enexprs(...)
 
@@ -38,3 +40,10 @@ dt_distinct <- function(.data, ...) {
       unique()
   }
 }
+
+#' @export
+dt_distinct.data.frame <- function(.data, ...) {
+  .data <- as_tidytable(.data)
+
+  dt_distinct(.data, ...)
+}
