@@ -9,7 +9,7 @@
 #' Supports enhanced selection
 #'
 #' @param .data The data table to pivot longer
-#' @param cols Column selection. If empty, uses all columns. Can use -colname to unselect column(s)
+#' @param cols Vector of bare column names. Can add/drop columns.
 #' @param names_to Name of the new "names" column. Must be a string.
 #' @param values_to Name of the new "values" column. Must be a string.
 #' @param values_drop_na If TRUE, rows will be dropped that contain NAs.
@@ -34,31 +34,34 @@
 #'
 #' @export
 dt_pivot_longer <- function(.data,
-                            cols = NULL,
+                            cols = dt_everything(),
                             names_to = "name",
                             values_to = "value",
                             values_drop_na = FALSE,
                             ...) {
+  UseMethod("dt_pivot_longer")
+}
 
-  if (!is.data.frame(.data)) stop("dt_ must be a data.frame or data.table")
-  if (!is.data.table(.data)) .data <- as.data.table(.data)
+#' @export
+dt_pivot_longer.tidytable <- function(.data,
+                                       cols = dt_everything(),
+                                       names_to = "name",
+                                       values_to = "value",
+                                       values_drop_na = FALSE,
+                                       ...) {
 
   names <- colnames(.data)
   cols <- enexpr(cols)
 
-  if (is.null(cols)) {
-    # All columns if cols = NULL
-    cols <- names
-  } else {
-    cols <- vec_selector(.data, !!cols) %>%
-      as.character()
-  }
+  cols <- vec_selector(.data, !!cols) %>%
+    as.character()
 
   if (length(cols) == 0) warning("No columns remaining after removing")
 
   id_vars <- names[!names %in% cols]
 
-  melt(data = .data,
+  as_tidytable(
+    melt(data = .data,
        id.vars = id_vars,
        measure.vars = cols,
        variable.name = names_to,
@@ -66,5 +69,23 @@ dt_pivot_longer <- function(.data,
        ...,
        na.rm = values_drop_na,
        variable.factor = FALSE,
-       value.factor = FALSE)
+       value.factor = FALSE))
+}
+
+#' @export
+dt_pivot_longer.data.frame <- function(.data,
+                                       cols = dt_everything(),
+                                       names_to = "name",
+                                       values_to = "value",
+                                       values_drop_na = FALSE,
+                                       ...) {
+  .data <- as_tidytable(.data)
+  cols <- enexpr(cols)
+
+  .data <- dt_pivot_longer(
+    .data, !!cols,
+    names_to = names_to, values_to = values_to,
+    values_drop_na = values_drop_na, ...)
+
+  .data
 }
