@@ -3,7 +3,7 @@
 #' @description
 #' The dt_map functions transform their input by applying a function to each element and returning a vector the same length as the input.
 #' * `dt_map()` returns a list
-#' * `_lgl()`, `_int()`, `_dbl()` and `_chr()` variants return their specified type
+#' * `_lgl()`, `_int()`, `_dbl()`,`_chr()`, `_df()` variants return their specified type
 #' * `_dfr()` & `_dfc()` Return data frame results binded together
 #'
 #' @param .x A list or vector
@@ -72,11 +72,15 @@ dt_map_dfc <- function(.x, .f, ...) {
 dt_map_dfr <- function(.x, .f, ..., .id = NULL) {
   .f <- anon_x(.f)
 
-  result_list<- dt_map(.x, .f, ...)
+  result_list <- dt_map(.x, .f, ...)
 
   dt_bind_rows(result_list, .id = .id)
 }
 
+#' @export
+#' @rdname dt_map
+dt_map_df <- dt_map_dfr
+
 #' @export
 #' @rdname dt_map
 dt_walk <- function(.x, .f, ...) {
@@ -145,11 +149,16 @@ dt_map2_dfr <- function(.x, .y, .f, ..., .id = NULL) {
   dt_bind_rows(result_list, .id = .id)
 }
 
+#' @export
+#' @rdname dt_map
+dt_map2_df <- dt_map2_dfr
+
 anon_x <- function(fn) {
   if (is_formula(fn)) {
     fn %>%
-      deparse() %>%
-      dt_str_replace("^~", "function(.x)") %>%
+      deparse(200L) %>%
+      str_c(collapse = "") %>%
+      str_replace("^~", "function(.x)") %>%
       parse_expr() %>%
       eval()
   } else {
@@ -160,8 +169,9 @@ anon_x <- function(fn) {
 anon_xy <- function(fn) {
   if (is_formula(fn)) {
     fn %>%
-      deparse() %>%
-      dt_str_replace("^~", "function(.x,.y)") %>%
+      deparse(200L) %>%
+      str_c(collapse = "") %>%
+      str_replace("^~", "function(.x,.y)") %>%
       parse_expr() %>%
       eval()
   } else {
