@@ -16,9 +16,11 @@
 #'   dt_rename(new_x = x,
 #'             new_y = y)
 dt_rename <- function(.data, ...) {
+  UseMethod("dt_rename")
+}
 
-  if (!is.data.frame(.data)) stop(".data must be a data.frame or data.table")
-  if (!is.data.table(.data)) .data <- as.data.table(.data)
+#' @export
+dt_rename.tidytable <- function(.data, ...) {
 
   dots <- enexprs(...)
   .data <- shallow(.data)
@@ -30,3 +32,10 @@ dt_rename <- function(.data, ...) {
 
   .data
 }
+
+#' @export
+dt_rename.data.frame <- function(.data, ...) {
+  .data <- as_tidytable(.data)
+
+  dt_rename(.data, ...)
+}
