@@ -30,7 +30,7 @@ dt_starts_with <- function(match) {
   .names <- .names[!.names %in% c("is.integer", "is.double", "is.numeric",
                                   "is.character", "is.factor", "is.logical")]
 
-  seq_along(.names)[dt_str_starts(.names, match)]
+  seq_along(.names)[str_starts(.names, match)]
 }
 
 #' @export
@@ -40,7 +40,7 @@ dt_contains <- function(match) {
   .names <- .names[!.names %in% c("is.integer", "is.double", "is.numeric",
                                   "is.character", "is.factor", "is.logical")]
 
-  seq_along(.names)[dt_str_detect(.names, match)]
+  seq_along(.names)[str_detect(.names, match)]
 }
 
 #' @export
@@ -50,7 +50,7 @@ dt_ends_with <- function(match) {
   .names <- .names[!.names %in% c("is.integer", "is.double", "is.numeric",
                                   "is.character", "is.factor", "is.logical")]
 
-  seq_along(.names)[dt_str_ends(.names, match)]
+  seq_along(.names)[str_ends(.names, match)]
 }
 
 #' @export
