@@ -1,5 +1,5 @@
 test_that("dt_distinct() works on all rows", {
-  test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"))
+  test_df <- tidytable(a = 1:3, b = 4:6, c = c("a", "a", "b"))
   distinct_df <- test_df %>%
     dt_distinct()
 
@@ -7,6 +7,15 @@ test_that("dt_distinct() works on all rows", {
   expect_equal(test_df, distinct_df)
 })
 
+test_that("dt_distinct() works on a data.frame", {
+  test_df <- data.frame(a = 1:3, b = 4:6, c = c("a", "a", "b"))
+  distinct_df <- test_df %>%
+    dt_distinct()
+
+  expect_equal(names(test_df), names(distinct_df))
+  expect_equal(as_tidytable(test_df), distinct_df)
+})
+
 test_that("dt_distinct() works on 1 column", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
