@@ -1,6 +1,5 @@
 # tests from tidyr regarding pivot_longer
 
-
 test_that("can pivot all cols (unspecified) to long", {
   df <- data.table(x = 1:2, y = 3:4)
   pivot_df <- dt_pivot_longer(df)[order(name, value)]
@@ -10,6 +9,15 @@ test_that("can pivot all cols (unspecified) to long", {
   expect_equal(pivot_df$value, c(1,2,3,4))
 })
 
+test_that("can pivot all cols (unspecified) to long with data.frame", {
+  df <- data.frame(x = 1:2, y = 3:4)
+  pivot_df <- dt_pivot_longer(df)[order(name, value)]
+
+  expect_named(pivot_df, c("name", "value"))
+  expect_equal(pivot_df$name, c("x","x","y","y"))
+  expect_equal(pivot_df$value, c(1,2,3,4))
+})
+
 
 test_that("can pivot all cols (specified) to long", {
   df <- data.table(x = 1:2, y = 3:4)
@@ -33,7 +41,8 @@ test_that("can select a single column", {
 })
 
 test_that("preserves original keys", {
-  df <- data.table(x = 1:2, y = 2, z = 1:2)
+  df <- data.table(x = 1:2, y = 2, z = 1:2) %>%
+    dt_mutate_all(as.double)
   pivot_df <- dt_pivot_longer(df, cols = c(y, z))[order(name, value)]
 
   expect_named(pivot_df, c("x", "name", "value"))
@@ -67,7 +76,8 @@ test_that("stops if given vector", {
 })
 
 test_that("works with select helpers", {
-  df <- data.table(x = 1:2, y = 2, z = 1:2)
+  df <- data.table(x = 1:2, y = 2, z = 1:2) %>%
+    dt_mutate_all(as.double)
   pivot_df <- dt_pivot_longer(df, cols = c(dt_starts_with("y"), dt_contains("z")))[order(name, value)]
 
   expect_named(pivot_df, c("x", "name", "value"))
