@@ -12,3 +12,11 @@ test_that("returns a vec", {
 
   expect_equal(test_df$y, result_vec)
 })
+
+test_that("returns a vec with data.frame input", {
+  test_df <- data.frame(x = c(1,2,3), y = c(4,5,6))
+  result_vec <- test_df %>%
+    dt_pull(y)
+
+  expect_equal(test_df$y, result_vec)
+})
