@@ -6,6 +6,14 @@ test_that("rename() works for one column", {
   expect_named(df, c("new_x", "y", "z"))
 })
 
+test_that("rename() works for one column w/ data.frame", {
+  df <- data.frame(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
+  df <- df %>%
+    dt_rename(new_x = x)
+
+  expect_named(df, c("new_x", "y", "z"))
+})
+
 test_that("rename() works for multiple columns", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
@@ -47,14 +55,22 @@ test_that("rename_all() works for all variables", {
   expect_named(df, c("x_append", "y_append"))
 })
 
+test_that("rename_all() works for all variables w/ data.frame", {
+  df <- data.frame(x = c(1,1,1), y = c(2,2,2))
+  df <- df %>%
+    dt_rename_all(function(.x) paste0(.x, "_append"))
+
+  expect_named(df, c("x_append", "y_append"))
+})
+
 # twiddle testing -----------------------------------
 test_that("rename_if() works with twiddle", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   anon_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_if(is.character, function(.x) paste0(.x, "_character"))
   twiddle_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_if(is.character, ~ paste0(.x, "_character"))
 
   expect_named(twiddle_df, c("x","y","z_character"))
@@ -64,10 +80,10 @@ test_that("rename_if() works with twiddle", {
 test_that("rename_at() works with twiddle", {
   df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
   anon_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_at(c(dt_starts_with("x")), ~ paste0(.x, "_append"))
   twiddle_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_at(c(dt_starts_with("x")), ~ paste0(.x, "_append"))
 
   expect_named(twiddle_df, c("x_start_append", "end_x", "z"))
@@ -77,10 +93,10 @@ test_that("rename_at() works with twiddle", {
 test_that("rename_across() works with twiddle", {
   df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
   anon_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_across(c(dt_starts_with("x")), ~ paste0(.x, "_append"))
   twiddle_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_across(c(dt_starts_with("x")), ~ paste0(.x, "_append"))
 
   expect_equal(anon_df, twiddle_df)
@@ -89,11 +105,11 @@ test_that("rename_across() works with twiddle", {
 test_that("rename_all() works with twiddle", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2))
   anon_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_all(function(.x) paste0(.x, "_append"))
 
   twiddle_df <- df %>%
-    as_dt() %>%
+    as_tidytable() %>%
     dt_rename_all(~ paste0(.x, "_append"))
 
   expect_named(twiddle_df, c("x_append", "y_append"))
